# Animation Options

Animation commands are used to create and control object-based and image-based animations in the viewport.

## Other Classes

```{eval-rst}

.. toggle::

    .. autoclass:: abaqus.Animation.AnimationOptions.AnimationOptions
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Animation.AnimationSession.AnimationSession
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Animation.AVIOptions.AVIOptions
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Animation.ImageAnimation.ImageAnimation
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Animation.ImageAnimationOptions.ImageAnimationOptions
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Animation.Movie.Movie
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Animation.QuickTimeOptions.QuickTimeOptions
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::
```
